==> hls_player-2.8.1.tar.gz: android/src/main/java/cl/axg/hls_player/HlsPlayerPlugin.java <==
package cl.axg.hls_player;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;

import android.text.TextUtils;
import android.util.Log;
import androidx.annotation.NonNull;
import android.net.Uri;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.ExoPlayer;

import io.flutter.app.FlutterActivity;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.FlutterEngineCache;
import io.flutter.embedding.engine.dart.DartExecutor;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import java.util.ArrayList;

/** HlsPlayerPlugin */
public class HlsPlayerPlugin implements  MethodCallHandler, FlutterPlugin  {

    private Context applicationContext;
    private MethodChannel methodChannel;
    private EventChannel eventChannel;

    /** Plugin registration. */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        final HlsPlayerPlugin instance = new HlsPlayerPlugin();
        instance.onAttachedToEngine(registrar.context(), registrar.messenger());
    }

    @Override
    public void onAttachedToEngine(FlutterPluginBinding binding) {
        onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
    }

    private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
        this.applicationContext = applicationContext;
        methodChannel = new MethodChannel(messenger, "hls_player");
        methodChannel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
        applicationContext = null;
        methodChannel.setMethodCallHandler(null);
        methodChannel = null;
        eventChannel.setStreamHandler(null);
        eventChannel = null;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
           if (call.method.equals("initializeVideo")) {
                    String url  = call.argument("url");
                    if(TextUtils.isEmpty(url)){
            
                         result.error( "Argumento invalido", "ha olvidado el parametro url", "se espera 1 string en formato URL de video HLS");
                         return;
                    } 

                        try{
                                Intent browserIntent = new Intent(this.applicationContext, MainActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("url", url);
                            this.applicationContext.startActivity(browserIntent);
                        }catch (Exception e){
                             Log.d("Catch error",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                        }

        } 
        if (call.method.equals("initializeZapping")) {


   try{
                       String  canales  = call.argument("canales");
                       int  playVideoAtIndex  = call.argument("playVideoAtIndex");
                       boolean  isSearchingItem  = call.argument("isSearchingItem");
                       String  urlEPG  = call.argument("urlEPG");

                                Intent browserIntent = new Intent(this.applicationContext, ZappingActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("canales", canales);
                                browserIntent.putExtra("playVideoAtIndex", playVideoAtIndex);
                                browserIntent.putExtra("isSearchingItem", isSearchingItem);
                                   browserIntent.putExtra("urlEPG", urlEPG);

                                this.applicationContext.startActivity(browserIntent);
                                    result.success(canales);

                    }catch (Exception e)
                    {
                             Log.d("hls_player",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                    } 
        }
           if (call.method.equals("getVideoLink")) {
                final  String getCurrentVideoLink = ZappingActivity.canales.get(ZappingActivity.playVideoAtIndex).getLinkReproductor();
                Log.d("hls_player", "video que se esta reproduciendo: "+getCurrentVideoLink);
                                    result.success(getCurrentVideoLink);
                      

        }
        if (call.method.equals("closeZapping")) {
            Log.d("hls_player","close Zapping");
            ZappingActivity.activity.finish();
            result.success(true);
        }
        if (call.method.equals("closeBuscador")) {
            Log.d("hls_player","close Buscador");
            MainActivity.activity.finish();
            result.success(true);
        }
        if (call.method.equals("syncMasivo")) {
            Log.d("hls_player","syncMasivo");
            String url  = call.argument("url");
            if(TextUtils.isEmpty(url)){
            
                result.error( "Argumento invalido", "ha olvidado el parametro url", "se espera 1 string en formato URL de video HLS");
                return;
            }

            try{

                final Common common = new Common();
                ExoPlayer player =  ZappingActivity.player;
                player.addMediaSource(common.getMediaSource(Uri.parse(url), null));
                player.setPlayWhenReady(true);
                player.seekTo(ZappingActivity.player.getMediaItemCount() - 1, C.INDEX_UNSET);
                player.prepare();
                ZappingActivity.isMasivo = true;
                result.success(true);

            }
            catch (Exception e)
            {
                Log.d("hls_player",e.getMessage());
                 result.error( "Catch error", e.getMessage(),null);
                return;
            } 
        }
        if (call.method.equals("offMasivo")) {
            Log.d("hls_player","offMasivo");

            try{
                ZappingActivity.isMasivo = false;
                ExoPlayer player =  ZappingActivity.player;

                if(player.getMediaItemCount() > 0){
                    player.setPlayWhenReady(true);
                    player.removeMediaItem(player.getCurrentMediaItemIndex());
                    player.prepare();
                    result.success(true);
                }else{
                    result.success(false);
                }

                }
                catch (Exception e)
                {
                    Log.d("hls_player",e.getMessage());
                    result.error( "Catch error", e.getMessage(),null);
                    return;
                } 
        }
        else {
            result.notImplemented();
        }
    }

}

==> hls_player-2.8.2.tar.gz: android/src/main/java/cl/axg/hls_player/HlsPlayerPlugin.java <==
package cl.axg.hls_player;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;

import android.text.TextUtils;
import android.util.Log;
import androidx.annotation.NonNull;

import io.flutter.app.FlutterActivity;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.FlutterEngineCache;
import io.flutter.embedding.engine.dart.DartExecutor;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import java.util.ArrayList;

/** HlsPlayerPlugin */
public class HlsPlayerPlugin implements  MethodCallHandler, FlutterPlugin  {

    private Context applicationContext;
    private MethodChannel methodChannel;
    private EventChannel eventChannel;

    /** Plugin registration. */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        final HlsPlayerPlugin instance = new HlsPlayerPlugin();
        instance.onAttachedToEngine(registrar.context(), registrar.messenger());
    }

    @Override
    public void onAttachedToEngine(FlutterPluginBinding binding) {
        onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
    }

    private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
        this.applicationContext = applicationContext;
        methodChannel = new MethodChannel(messenger, "hls_player");
        methodChannel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
        applicationContext = null;
        methodChannel.setMethodCallHandler(null);
        methodChannel = null;
        eventChannel.setStreamHandler(null);
        eventChannel = null;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
           if (call.method.equals("initializeVideo")) {
                    String url  = call.argument("url");
                    if(TextUtils.isEmpty(url)){
            
                         result.error( "Argumento invalido", "ha olvidado el parametro url", "se espera 1 string en formato URL de video HLS");
                         return;
                    } 

                        try{
                                Intent browserIntent = new Intent(this.applicationContext, MainActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("url", url);
                            this.applicationContext.startActivity(browserIntent);
                        }catch (Exception e){
                             Log.d("Catch error",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                        }

        } 
        if (call.method.equals("initializeZapping")) {


   try{
                       String  canales  = call.argument("canales");
                       int  playVideoAtIndex  = call.argument("playVideoAtIndex");
                       boolean  isSearchingItem  = call.argument("isSearchingItem");
                       String  urlEPG  = call.argument("urlEPG");

                                Intent browserIntent = new Intent(this.applicationContext, ZappingActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("canales", canales);
                                browserIntent.putExtra("playVideoAtIndex", playVideoAtIndex);
                                browserIntent.putExtra("isSearchingItem", isSearchingItem);
                                   browserIntent.putExtra("urlEPG", urlEPG);

                                this.applicationContext.startActivity(browserIntent);
                                    result.success(canales);

                    }catch (Exception e)
                    {
                             Log.d("hls_player",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                    } 
        }
           if (call.method.equals("getVideoLink")) {
                final  String getCurrentVideoLink = ZappingActivity.canales.get(playerc.getCurrentMediaItemIndex()).getLinkReproductor();
                Log.d("hls_player", "video que se esta reproduciendo: "+getCurrentVideoLink);
                                    result.success(getCurrentVideoLink);
                      

        }
        if (call.method.equals("closeZapping")) {
            Log.d("hls_player","close Zapping");
            ZappingActivity.activity.finish();
            result.success(true);
        }
        if (call.method.equals("closeBuscador")) {
            Log.d("hls_player","close Buscador");
            MainActivity.activity.finish();
            result.success(true);
        }
        else {
            result.notImplemented();
        }
    }

}
